"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const createDataStorePredicate_1 = require("../createDataStorePredicate");
const namePredicateObject = {
    field: 'name',
    operator: 'startsWith',
    operand: 'John',
};
const agePredicateObject = {
    field: 'age',
    operator: 'gt',
    operand: '25',
};
const booleanPredicateObject = {
    field: 'isActive',
    operator: 'eq',
    operand: true,
};
const agePredicate = jest.fn();
const booleanPredicate = jest.fn();
const namePredicate = jest.fn();
const baseCondition = {
    id: '',
    name: '',
    age: '',
};
const ageCondition = {
    ...baseCondition,
    [agePredicateObject.field]: {
        [agePredicateObject.operator]: agePredicate,
    },
};
const booleanCondition = {
    ...baseCondition,
    [booleanPredicateObject.field]: {
        [booleanPredicateObject.operator]: booleanPredicate,
    },
};
const nameCondition = {
    ...baseCondition,
    [namePredicateObject.field]: {
        [namePredicateObject.operator]: namePredicate,
    },
};
describe('createDataStorePredicate', () => {
    beforeEach(() => {
        jest.clearAllMocks();
    });
    test('should generate a simple predicate', () => {
        const predicate = (0, createDataStorePredicate_1.createDataStorePredicate)(namePredicateObject);
        predicate(nameCondition);
        expect(namePredicate).toHaveBeenCalledWith(namePredicateObject.operand);
    });
    test('should generate a simple boolean predicate', () => {
        const predicate = (0, createDataStorePredicate_1.createDataStorePredicate)(booleanPredicateObject);
        predicate(booleanCondition);
        expect(booleanPredicate).toHaveBeenCalledWith(booleanPredicateObject.operand);
    });
    test('should generate an `or` group predicate', () => {
        const predicateObject = {
            or: [namePredicateObject, agePredicateObject],
        };
        const predicate = (0, createDataStorePredicate_1.createDataStorePredicate)(predicateObject);
        const or = (p) => [p(nameCondition), p(ageCondition)];
        const condition = {
            or,
        };
        predicate(condition);
        expect(namePredicate).toHaveBeenCalledWith(namePredicateObject.operand);
        expect(agePredicate).toHaveBeenCalledWith(agePredicateObject.operand);
    });
    test('should generate an `and` group predicate', () => {
        const predicateObject = {
            and: [namePredicateObject, agePredicateObject],
        };
        const predicate = (0, createDataStorePredicate_1.createDataStorePredicate)(predicateObject);
        const and = (p) => [p(nameCondition), p(ageCondition)];
        const condition = {
            and,
        };
        predicate(condition);
        expect(namePredicate).toHaveBeenCalledWith(namePredicateObject.operand);
        expect(agePredicate).toHaveBeenCalledWith(agePredicateObject.operand);
    });
    test('should generate a nested predicate', () => {
        const predicateObject = {
            and: [namePredicateObject, { or: [agePredicateObject] }],
        };
        const predicate = (0, createDataStorePredicate_1.createDataStorePredicate)(predicateObject);
        const or = (orGroup) => orGroup(ageCondition);
        const condition = {
            and: (andGroup) => andGroup({
                ...nameCondition,
                or,
            }),
        };
        predicate(condition);
        expect(namePredicate).toHaveBeenCalledWith(namePredicateObject.operand);
        expect(agePredicate).toHaveBeenCalledWith(agePredicateObject.operand);
    });
});
//# sourceMappingURL=createDataStorePredicate.test.js.map