"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

  Licensed under the Apache License, Version 2.0 (the "License").
  You may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
const aws_amplify_1 = require("aws-amplify");
const constants_1 = require("../constants");
const useDataStoreDeleteAction_1 = require("../useDataStoreDeleteAction");
const models_1 = require("./test-models/models");
const amplify_symbol_1 = require("../../amplify-symbol");
jest.mock('aws-amplify');
const deleteSpy = jest.spyOn(aws_amplify_1.DataStore, 'delete');
const hubDispatchSpy = jest.spyOn(aws_amplify_1.Hub, 'dispatch');
const id = '1234';
const dataStoreDeleteArgs = {
    model: models_1.Todo,
    id,
};
describe('useDataStoreDeleteAction', () => {
    beforeEach(() => jest.clearAllMocks());
    it('should call DataStore.delete', async () => {
        const action = (0, useDataStoreDeleteAction_1.useDataStoreDeleteAction)(dataStoreDeleteArgs);
        await action();
        expect(deleteSpy).toHaveBeenCalledTimes(1);
    });
    it('should call Hub with started and finished events', async () => {
        const action = (0, useDataStoreDeleteAction_1.useDataStoreDeleteAction)(dataStoreDeleteArgs);
        await action();
        expect(hubDispatchSpy).toHaveBeenCalledTimes(2);
        expect(hubDispatchSpy).toHaveBeenCalledWith(constants_1.UI_CHANNEL, {
            data: { id },
            event: constants_1.ACTION_DATASTORE_DELETE_STARTED,
        }, constants_1.EVENT_ACTION_DATASTORE_DELETE, amplify_symbol_1.AMPLIFY_SYMBOL);
        expect(hubDispatchSpy).toHaveBeenCalledWith(constants_1.UI_CHANNEL, {
            data: { id },
            event: constants_1.ACTION_DATASTORE_DELETE_FINISHED,
        }, constants_1.EVENT_ACTION_DATASTORE_DELETE, amplify_symbol_1.AMPLIFY_SYMBOL);
    });
    it('should call Hub with error message if DataStore.delete rejects', async () => {
        const errorMessage = 'Invalid data model';
        deleteSpy.mockImplementation(() => Promise.reject(new Error(errorMessage)));
        const action = (0, useDataStoreDeleteAction_1.useDataStoreDeleteAction)(dataStoreDeleteArgs);
        await action();
        expect(hubDispatchSpy).toHaveBeenCalledTimes(2);
        expect(hubDispatchSpy).toHaveBeenCalledWith(constants_1.UI_CHANNEL, {
            data: { id },
            event: constants_1.ACTION_DATASTORE_DELETE_STARTED,
        }, constants_1.EVENT_ACTION_DATASTORE_DELETE, amplify_symbol_1.AMPLIFY_SYMBOL);
        expect(hubDispatchSpy).toHaveBeenCalledWith(constants_1.UI_CHANNEL, {
            data: {
                id,
                errorMessage,
            },
            event: constants_1.ACTION_DATASTORE_DELETE_FINISHED,
        }, constants_1.EVENT_ACTION_DATASTORE_DELETE, amplify_symbol_1.AMPLIFY_SYMBOL);
    });
});
//# sourceMappingURL=useDataStoreDeleteAction.test.js.map