"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

  Licensed under the Apache License, Version 2.0 (the "License").
  You may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
const aws_amplify_1 = require("aws-amplify");
const react_hooks_1 = require("@testing-library/react-hooks");
const constants_1 = require("../constants");
const useNavigateAction_1 = require("../useNavigateAction");
const amplify_symbol_1 = require("../../amplify-symbol");
jest.mock('aws-amplify');
describe('useNavigateHook:', () => {
    let windowSpy;
    const url = 'https://www.amazon.com/';
    const target = '_blank';
    const anchor = '#about';
    beforeEach(() => {
        jest.clearAllMocks();
    });
    const testHubEventEmit = (data) => {
        expect(aws_amplify_1.Hub.dispatch).toHaveBeenCalledTimes(2);
        expect(aws_amplify_1.Hub.dispatch).toHaveBeenCalledWith(constants_1.UI_CHANNEL, {
            event: constants_1.ACTION_NAVIGATE_STARTED,
            data,
        }, constants_1.EVENT_ACTION_CORE_NAVIGATE, amplify_symbol_1.AMPLIFY_SYMBOL);
        expect(aws_amplify_1.Hub.dispatch).toHaveBeenLastCalledWith(constants_1.UI_CHANNEL, {
            event: constants_1.ACTION_NAVIGATE_FINISHED,
            data,
        }, constants_1.EVENT_ACTION_CORE_NAVIGATE, amplify_symbol_1.AMPLIFY_SYMBOL);
    };
    it('Should call window.open', () => {
        windowSpy = jest.spyOn(window, 'open').mockImplementation(() => {
            return window;
        });
        const config = {
            type: 'url',
            url,
        };
        const { result } = (0, react_hooks_1.renderHook)(() => (0, useNavigateAction_1.useNavigateAction)(config));
        result.current();
        expect(windowSpy).toBeCalledTimes(1);
        expect(windowSpy).toBeCalledWith(url, useNavigateAction_1.defaultTarget, useNavigateAction_1.windowFeatures);
        testHubEventEmit(config);
        windowSpy.mockRestore();
    });
    it('Should call window.open with "_blank" as target', () => {
        windowSpy = jest.spyOn(window, 'open').mockImplementation(() => {
            return window;
        });
        const config = {
            type: 'url',
            url,
            target,
        };
        const { result } = (0, react_hooks_1.renderHook)(() => (0, useNavigateAction_1.useNavigateAction)(config));
        result.current();
        expect(windowSpy).toBeCalledTimes(1);
        expect(windowSpy).toBeCalledWith(url, target, useNavigateAction_1.windowFeatures);
        testHubEventEmit(config);
        windowSpy.mockRestore();
    });
    it('Should change window location hash', () => {
        const config = {
            type: 'anchor',
            anchor,
        };
        const { result } = (0, react_hooks_1.renderHook)(() => (0, useNavigateAction_1.useNavigateAction)(config));
        expect(window.location.hash).toBe('');
        result.current();
        expect(window.location.hash).toBe(anchor);
        testHubEventEmit(config);
    });
    it('Should call window.reload', () => {
        Object.defineProperty(window, 'location', {
            value: {
                reload: jest.fn(),
            },
        });
        const config = {
            type: 'reload',
        };
        const { result } = (0, react_hooks_1.renderHook)(() => (0, useNavigateAction_1.useNavigateAction)(config));
        result.current();
        expect(window.location.reload).toBeCalledTimes(1);
        testHubEventEmit(config);
    });
});
//# sourceMappingURL=useNavigateAction.test.js.map