"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

  Licensed under the Apache License, Version 2.0 (the "License").
  You may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
const aws_amplify_1 = require("aws-amplify");
const react_hooks_1 = require("@testing-library/react-hooks");
const constants_1 = require("../constants");
const useStateMutationAction_1 = require("../useStateMutationAction");
const amplify_symbol_1 = require("../../amplify-symbol");
jest.mock('aws-amplify');
describe('useStateMutationAction:', () => {
    it('should update state correctly', () => {
        const prevState = 'none';
        const newState = 'block';
        const data = { prevState, newState };
        const { result } = (0, react_hooks_1.renderHook)(() => (0, useStateMutationAction_1.useStateMutationAction)(prevState));
        (0, react_hooks_1.act)(() => {
            const [, setNewState] = result.current;
            setNewState(newState);
        });
        const [state] = result.current;
        expect(state).toBe(newState);
        expect(aws_amplify_1.Hub.dispatch).toHaveBeenCalledTimes(2);
        expect(aws_amplify_1.Hub.dispatch).toHaveBeenCalledWith(constants_1.UI_CHANNEL, {
            event: constants_1.ACTION_STATE_MUTATION_STARTED,
            data,
        }, constants_1.EVENT_ACTION_CORE_STATE_MUTATION, amplify_symbol_1.AMPLIFY_SYMBOL);
        expect(aws_amplify_1.Hub.dispatch).toHaveBeenLastCalledWith(constants_1.UI_CHANNEL, {
            event: constants_1.ACTION_STATE_MUTATION_FINISHED,
            data,
        }, constants_1.EVENT_ACTION_CORE_STATE_MUTATION, amplify_symbol_1.AMPLIFY_SYMBOL);
    });
});
//# sourceMappingURL=useStateMutationAction.test.js.map