"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createDataStorePredicateString = exports.createDataStorePredicate = void 0;
function isModelKey(field) {
    return !!field;
}
const isOperatorKey = (operator) => !!operator;
/**
 * Given an array of predicates, compose them in sequential order
 */
const mergePredicates = (predicates) => {
    return (model) => predicates.map((predicate) => predicate(model));
};
/**
 * Creates a DataStore compatible predicate function from an object representation
 * @internal
 */
const createDataStorePredicate = (predicateObject) => {
    const { and: groupAnd, or: groupOr, field, operator, operand } = predicateObject;
    if (Array.isArray(groupAnd)) {
        const predicates = groupAnd.map((condition) => (0, exports.createDataStorePredicate)(condition));
        return (p) => p.and(mergePredicates(predicates));
    }
    if (Array.isArray(groupOr)) {
        const predicates = groupOr.map((condition) => (0, exports.createDataStorePredicate)(condition));
        return (p) => p.or(mergePredicates(predicates));
    }
    return (p) => {
        var _a;
        if (isModelKey(field) && isOperatorKey(operator) && ((_a = p === null || p === void 0 ? void 0 : p[field]) === null || _a === void 0 ? void 0 : _a[operator])) {
            return p[field][operator](operand);
        }
        return p;
    };
};
exports.createDataStorePredicate = createDataStorePredicate;
exports.createDataStorePredicateString = `export const createDataStorePredicate = <Model extends PersistentModel>(
  predicateObject: DataStorePredicateObject
): RecursiveModelPredicateExtender<Model> => {
  const {
    and: groupAnd,
    or: groupOr,
    field,
    operator,
    operand,
  } = predicateObject;

  if (Array.isArray(groupAnd)) {
    const predicates = groupAnd.map((condition) =>
      createDataStorePredicate<Model>(condition)
    );

    return (p: RecursiveModelPredicate<Model>) =>
      p.and((model) => predicates.map((predicate) => predicate(model)));
  }

  if (Array.isArray(groupOr)) {
    const predicates = groupOr.map((condition) =>
      createDataStorePredicate<Model>(condition)
    );

    return (p: RecursiveModelPredicate<Model>) =>
      p.or((model) => predicates.map((predicate) => predicate(model)));
  }

  return (p: RecursiveModelPredicate<Model>) => {
    if (
      !!field &&
      !!operator &&
      p?.[field]?.[operator]
    ) {
      return (p[field][operator] as Function)(
        operand
      ) as RecursiveModelPredicate<Model>;
    }

    return p;
  };
};`;
//# sourceMappingURL=createDataStorePredicate.js.map