"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useAuthSignOutActionString = exports.useAuthSignOutAction = void 0;
const aws_amplify_1 = require("aws-amplify");
const amplify_symbol_1 = require("../amplify-symbol");
const get_error_message_1 = require("../get-error-message");
const constants_1 = require("./constants");
const useAuthSignOutAction = (options) => async () => {
    try {
        aws_amplify_1.Hub.dispatch(constants_1.UI_CHANNEL, {
            event: constants_1.ACTION_AUTH_SIGNOUT_STARTED,
            data: { options },
        }, constants_1.EVENT_ACTION_AUTH_SIGNOUT, amplify_symbol_1.AMPLIFY_SYMBOL);
        await aws_amplify_1.Auth.signOut(options);
        aws_amplify_1.Hub.dispatch(constants_1.UI_CHANNEL, {
            event: constants_1.ACTION_AUTH_SIGNOUT_FINISHED,
            data: { options },
        }, constants_1.EVENT_ACTION_AUTH_SIGNOUT, amplify_symbol_1.AMPLIFY_SYMBOL);
    }
    catch (error) {
        aws_amplify_1.Hub.dispatch(constants_1.UI_CHANNEL, {
            event: constants_1.ACTION_AUTH_SIGNOUT_FINISHED,
            data: { options, errorMessage: (0, get_error_message_1.getErrorMessage)(error) },
        }, constants_1.EVENT_ACTION_AUTH_SIGNOUT, amplify_symbol_1.AMPLIFY_SYMBOL);
    }
};
exports.useAuthSignOutAction = useAuthSignOutAction;
exports.useAuthSignOutActionString = `export const useAuthSignOutAction: UseAuthSignOutAction =
  (options) => async () => {
    try {
      Hub.dispatch(
        UI_CHANNEL,
        {
          event: ACTION_AUTH_SIGNOUT_STARTED,
          data: { options },
        },
        EVENT_ACTION_AUTH_SIGNOUT,
        AMPLIFY_SYMBOL
      );

      await Auth.signOut(options);
      Hub.dispatch(
        UI_CHANNEL,
        {
          event: ACTION_AUTH_SIGNOUT_FINISHED,
          data: { options },
        },
        EVENT_ACTION_AUTH_SIGNOUT,
        AMPLIFY_SYMBOL
      );
    } catch (error) {
      Hub.dispatch(
        UI_CHANNEL,
        {
          event: ACTION_AUTH_SIGNOUT_FINISHED,
          data: { options, errorMessage: getErrorMessage(error) },
        },
        EVENT_ACTION_AUTH_SIGNOUT,
        AMPLIFY_SYMBOL
      );
    }
  };`;
//# sourceMappingURL=useAuthSignoutAction.js.map