"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useDataStoreCreateActionString = exports.useDataStoreCreateAction = void 0;
const aws_amplify_1 = require("aws-amplify");
const constants_1 = require("./constants");
const useTypeCastFields_1 = require("./useTypeCastFields");
const amplify_symbol_1 = require("../amplify-symbol");
const get_error_message_1 = require("../get-error-message");
/**
 * Action to Create DataStore item
 * @internal
 */
const useDataStoreCreateAction = ({ model, fields: initialFields, schema, }) => {
    const fields = (0, useTypeCastFields_1.useTypeCastFields)({
        fields: initialFields,
        modelName: model.name,
        schema,
    });
    return async () => {
        try {
            aws_amplify_1.Hub.dispatch(constants_1.UI_CHANNEL, {
                event: constants_1.ACTION_DATASTORE_CREATE_STARTED,
                data: { fields },
            }, constants_1.EVENT_ACTION_DATASTORE_CREATE, amplify_symbol_1.AMPLIFY_SYMBOL);
            // eslint-disable-next-line new-cap
            const item = await aws_amplify_1.DataStore.save(new model(fields));
            aws_amplify_1.Hub.dispatch(constants_1.UI_CHANNEL, {
                event: constants_1.ACTION_DATASTORE_CREATE_FINISHED,
                data: { fields, item },
            }, constants_1.EVENT_ACTION_DATASTORE_CREATE, amplify_symbol_1.AMPLIFY_SYMBOL);
        }
        catch (error) {
            aws_amplify_1.Hub.dispatch(constants_1.UI_CHANNEL, {
                event: constants_1.ACTION_DATASTORE_CREATE_FINISHED,
                data: {
                    fields,
                    errorMessage: (0, get_error_message_1.getErrorMessage)(error),
                },
            }, constants_1.EVENT_ACTION_DATASTORE_CREATE, amplify_symbol_1.AMPLIFY_SYMBOL);
        }
    };
};
exports.useDataStoreCreateAction = useDataStoreCreateAction;
exports.useDataStoreCreateActionString = `export const useDataStoreCreateAction = <Model extends PersistentModel>({
  model,
  fields: initialFields,
  schema,
}: UseDataStoreCreateActionOptions<Model>): (() => Promise<void>) => {
  const fields = useTypeCastFields<Model>({
    fields: initialFields,
    modelName: model.name,
    schema,
  });

  return async () => {
    try {
      Hub.dispatch(
        UI_CHANNEL,
        {
          event: ACTION_DATASTORE_CREATE_STARTED,
          data: { fields },
        },
        EVENT_ACTION_DATASTORE_CREATE,
        AMPLIFY_SYMBOL
      );

      const item = await DataStore.save(new model(fields));

      Hub.dispatch(
        UI_CHANNEL,
        {
          event: ACTION_DATASTORE_CREATE_FINISHED,
          data: { fields, item },
        },
        EVENT_ACTION_DATASTORE_CREATE,
        AMPLIFY_SYMBOL
      );
    } catch (error) {
      Hub.dispatch(
        UI_CHANNEL,
        {
          event: ACTION_DATASTORE_CREATE_FINISHED,
          data: {
            fields,
            errorMessage: getErrorMessage(error),
          },
        },
        EVENT_ACTION_DATASTORE_CREATE,
        AMPLIFY_SYMBOL
      );
    }
  };
};`;
//# sourceMappingURL=useDataStoreCreateAction.js.map