"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useNavigateActionString = exports.useNavigateAction = exports.defaultTarget = exports.windowFeatures = void 0;
/*
  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

  Licensed under the Apache License, Version 2.0 (the "License").
  You may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
const React = __importStar(require("react"));
const aws_amplify_1 = require("aws-amplify");
const constants_1 = require("./constants");
const amplify_symbol_1 = require("../amplify-symbol");
exports.windowFeatures = 'noopener noreferrer';
exports.defaultTarget = '_self';
/**
 * Action to instruct user’s browser to change current location
 * @internal
 */
const useNavigateAction = (options) => {
    const { type, url, anchor, target } = options;
    const run = React.useMemo(() => {
        switch (type) {
            case 'url':
                return () => {
                    window.open(url, target || '_self', 'noopener noreferrer');
                };
            case 'anchor':
                return () => {
                    window.location.hash = anchor !== null && anchor !== void 0 ? anchor : '';
                };
            case 'reload':
                return () => {
                    window.location.reload();
                };
            default:
                return () => {
                    // eslint-disable-next-line no-console
                    console.warn('Please provide a valid navigate type. Available types are "url", "anchor" and "reload".');
                };
        }
    }, [anchor, target, type, url]);
    const navigateAction = () => {
        aws_amplify_1.Hub.dispatch(constants_1.UI_CHANNEL, {
            event: constants_1.ACTION_NAVIGATE_STARTED,
            data: options,
        }, constants_1.EVENT_ACTION_CORE_NAVIGATE, amplify_symbol_1.AMPLIFY_SYMBOL);
        run();
        aws_amplify_1.Hub.dispatch(constants_1.UI_CHANNEL, {
            event: constants_1.ACTION_NAVIGATE_FINISHED,
            data: options,
        }, constants_1.EVENT_ACTION_CORE_NAVIGATE, amplify_symbol_1.AMPLIFY_SYMBOL);
    };
    return navigateAction;
};
exports.useNavigateAction = useNavigateAction;
exports.useNavigateActionString = `export const useNavigateAction = (options: UseNavigateActionOptions) => {
  const { type, url, anchor, target } = options;
  const run = React.useMemo(() => {
    switch (type) {
      case 'url':
        return () => {
          window.open(url, target || '_self', 'noopener noreferrer');
        };
      case 'anchor':
        return () => {
          window.location.hash = anchor ?? '';
        };
      case 'reload':
        return () => {
          window.location.reload();
        };
      default:
        return () => {
          // eslint-disable-next-line no-console
          console.warn('Please provide a valid navigate type. Available types are "url", "anchor" and "reload".');
        };
    }
  }, [anchor, target, type, url]);

  const navigateAction = () => {
    Hub.dispatch(
      UI_CHANNEL,
      {
        event: ACTION_NAVIGATE_STARTED,
        data: options,
      },
      EVENT_ACTION_CORE_NAVIGATE,
      AMPLIFY_SYMBOL,
    );
    run();
    Hub.dispatch(
      UI_CHANNEL,
      {
        event: ACTION_NAVIGATE_FINISHED,
        data: options,
      },
      EVENT_ACTION_CORE_NAVIGATE,
      AMPLIFY_SYMBOL,
    );
  };

  return navigateAction;
};`;
//# sourceMappingURL=useNavigateAction.js.map