"use strict";
/*
  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

  Licensed under the Apache License, Version 2.0 (the "License").
  You may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useTypeCastFieldsString = exports.useTypeCastFields = void 0;
const React = __importStar(require("react"));
/**
 * Optimistically casts field string values to types required by
 * datastore based on the schema type
 * @see: See https://docs.aws.amazon.com/appsync/latest/devguide/scalars.html
 */
const useTypeCastFields = ({ fields, modelName, schema, }) => {
    return React.useMemo(() => {
        if (!schema) {
            return fields;
        }
        const castFields = {};
        Object.keys(fields).forEach((fieldName) => {
            var _a, _b, _c;
            const field = fields[fieldName];
            switch ((_c = (_b = (_a = schema === null || schema === void 0 ? void 0 : schema.models[modelName]) === null || _a === void 0 ? void 0 : _a.fields) === null || _b === void 0 ? void 0 : _b[fieldName]) === null || _c === void 0 ? void 0 : _c.type) {
                case 'AWSTimestamp':
                    castFields[fieldName] = Number(field);
                    break;
                case 'Boolean':
                    castFields[fieldName] = Boolean(field);
                    break;
                case 'Int':
                    castFields[fieldName] =
                        typeof field === 'string' ||
                            (typeof field === 'object' && Object.prototype.toString.call(field) === '[object String]')
                            ? parseInt(field, 10)
                            : field;
                    break;
                case 'Float':
                    castFields[fieldName] = Number(field);
                    break;
                default:
                    castFields[fieldName] = field;
                    break;
            }
        });
        return castFields;
    }, [fields, schema, modelName]);
};
exports.useTypeCastFields = useTypeCastFields;
exports.useTypeCastFieldsString = `export const useTypeCastFields = <Model extends PersistentModel>({
  fields,
  modelName,
  schema,
}: UseTypeCastFieldsProps): UseTypeCastFieldsReturn<Model> => {
  return React.useMemo(() => {
    if (!schema) {
      return fields;
    }

    const castFields: any = {};
    Object.keys(fields).forEach((fieldName: string) => {
      const field = fields[fieldName];
      switch (schema?.models[modelName]?.fields?.[fieldName]?.type) {
        case 'AWSTimestamp':
          castFields[fieldName] = Number(field);
          break;
        case 'Boolean':
          castFields[fieldName] = Boolean(field);
          break;
        case 'Int':
          castFields[fieldName] = (
            typeof field === 'string' ||
            (typeof field === 'object' &&
              Object.prototype.toString.call(field) === '[object String]')
          ) ? parseInt(field) : field;
          break;
        case 'Float':
          castFields[fieldName] = Number(field);
          break;
        default:
          castFields[fieldName] = field;
          break;
      }
    });

    return castFields;
  }, [fields, schema, modelName]);
};`;
//# sourceMappingURL=useTypeCastFields.js.map